@@ -112,6 +112,19 @@ void Chuck_VM_Object::add_ref()
 
 
 
+//-----------------------------------------------------------------------------
+// name: dec_ref_no_release() | 1.5.4.3 (ge) added
+// desc: decrement reference only; no deletion
+//-----------------------------------------------------------------------------
+void Chuck_VM_Object::dec_ref_no_release()
+{
+    // decrement
+    if( m_ref_count > 0 ) m_ref_count--;
+}
+
+
+
+
 //-----------------------------------------------------------------------------
 // name: release()
 // desc: decrement reference; deletes objects when refcount reaches 0;
@@ -328,7 +341,7 @@ Chuck_Object::~Chuck_Object()
         }
 
         // go up the inheritance
-        type = type->parent;
+        type = type->parent_type;
     }
 
     // release class-scope member vars | 1.5.2.0 (ge) added
@@ -346,7 +359,7 @@ Chuck_Object::~Chuck_Object()
         }
 
         // go up to parent type
-        type = type->parent;
+        type = type->parent_type;
     }
 
     // release origin shred
