@@ -402,6 +402,8 @@ struct Chuck_Context : public Chuck_VM_Object
 
     // AST (does not persist past context unloading)
     a_Program parse_tree;
+    // ckdoc pending @doc statement for this context | 1.5.4.5 (ge) added
+    a_Stmt_Doc stmt_doc;
 
     // progress
     enum ContextProgress { P_NONE = 0, P_IMPORTING, P_IMPORTED, P_ALL_DONE };
@@ -421,7 +423,8 @@ public:
 
 public:
     // constructor
-    Chuck_Context() { parse_tree = NULL; nspc = new Chuck_Namespace;
+    Chuck_Context () {
+        parse_tree = NULL; stmt_doc = NULL;  nspc = new Chuck_Namespace;
                       has_error = FALSE; progress = P_NONE; }
     // destructor
     virtual ~Chuck_Context();
@@ -1443,7 +1446,8 @@ t_CKBOOL type_engine_is_base_exp_static( Chuck_Env * env, a_Exp_Dot_Member exp )
 t_CKBOOL type_engine_binary_is_func_call( Chuck_Env * env, ae_Operator op, a_Exp lhs, a_Exp rhs ); // 1.5.4.3 (ge) added
 Chuck_Type  * type_engine_find_common_anc( Chuck_Type * lhs, Chuck_Type * rhs );
 Chuck_Type  * type_engine_find_type( Chuck_Env * env, a_Id_List path );
-Chuck_Type  * type_engine_find_type( Chuck_Env * env, const std::string & name ); // 1.5.0.0 (ge) added
+// 1.5.0.0 (ge) added | 1.5.4.5 (ge & alex) added expandToUser=TRUE optional argument
+Chuck_Type  * type_engine_find_type( Chuck_Env * env, const std::string & name, t_CKBOOL expandToUser = TRUE );
 Chuck_Value * type_engine_find_value( Chuck_Type * type, const std::string & xid );
 Chuck_Value * type_engine_find_value( Chuck_Type * type, S_Symbol xid );
 Chuck_Value * type_engine_find_value( Chuck_Env * env, const std::string & xid, t_CKBOOL climb, t_CKBOOL stayWithClassDef = FALSE, int linepos = 0 );
